'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var postcss = _interopDefault(require('postcss'));

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

var fontWeightNames = {
  'thin': 100,
  'extra-light': 200,
  'extralight': 200,
  'ultra-light': 200,
  'ultralight': 200,
  'light': 300,
  'book': 400,
  'normal': 400,
  'regular': 400,
  'roman': 400,
  'medium': 500,
  'semi-bold': 600,
  'semibold': 600,
  'demi-bold': 600,
  'demibold': 600,
  'bold': 700,
  'extra-bold': 800,
  'extrabold': 800,
  'ultra-bold': 800,
  'ultrabold': 800,
  'black': 900,
  'heavy': 900
};

var index = postcss.plugin('postcss-font-weights', opts => {
  // get the dashed prefix
  const prefix = 'prefix' in Object(opts) ? `-${opts.prefix}-` : ''; // get the (conditionally prefixed) property pattern

  const propertyRegExp = new RegExp(`^${prefix}(font(-weight)?)$`); // get the custom weights map

  const fontWeightMap = Object.assign({}, fontWeightNames, Object(opts).weights); // get the font-weight pattern

  const fontWeightRegExp = new RegExp(`(^|\\s)(${Object.keys(fontWeightMap).join('|')})(\\s|$)`);
  return root => {
    // walk each matching declaration
    root.walkDecls(propertyRegExp, decl => {
      // unprefixed property
      const _decl$prop$match = decl.prop.match(propertyRegExp),
            _decl$prop$match2 = _slicedToArray(_decl$prop$match, 2),
            property = _decl$prop$match2[1]; // conditionally remove the prefix from the property


      if (prefix) {
        decl.prop = property;
      } // conditionally replace the font weight in the value


      decl.value = decl.value.replace(fontWeightRegExp, ($0, beforeSpace, value, afterSpace) => `${beforeSpace}${fontWeightMap[value]}${afterSpace}` // eslint-disable-line max-params
      );
    });
  };
});

module.exports = index;
//# sourceMappingURL=index.cjs.js.map
